#!/usr/bin/python

# An example ho how to use the wrapper to Atima
# For questions to the wrapper: P.Boutachkov@gsi.de  tel. 2346

# Import the Atima module and math in case we want to take some sqrt or pow
import atima, math

def main():
# Example 197Au on Al with thickness of 10 mg/cm2
   print('Example 197Au on Al with thickness of 10 mg/cm2') 
   proj = [ 196.96655, 79 ]   # Projectile [Mass, Charge]
   targ = [[26.98154, 13, 1]] # List of target components 
                              #  [[mass number, charge, stochastic ratio],...] 
   density = 2.6989           # Target density on g/cm3
   isgas = 0                  # Is the target a gass 0/1 --> No/Yes
   targThickness = 10.0       # Target thickness in mg/cm2
   Ebeam = 1000.0             # Projectile energy in MeV/u
 
# Atima returns a tuple with the calculated value, see bellow or
# in atima.f for description 
   (Ein, Eout, projrange ,dEdXin, dEdXout, RemainingRange,  \
    RangeStraggling , EnegergyStraggling, AngularStraggling, \
     Tof, InterpolatedTargetThickness) \
      = atima.eloss(proj, Ebeam, targ, density, isgas, targThickness)
 
   print('Ein  [MeV/u]: ' , Ein)
   print('Eout [MeV/u]: ' ,Eout)
   print('Range [mg/cm2]: ',projrange)   
   print('dEdX_in [MeV/mg/cm2]: ' ,dEdXin*proj[0])
   print('dEdX out [MeV/mg/cm2]: ' ,dEdXout*proj[0])
   print('Remaing Range[mg/cm2]  : ' ,RemainingRange)
   print('Range straggling [mg/cm2]  : ' ,RangeStraggling)
   print('Energy Straggling  [MeV] : ' ,EnegergyStraggling*dEdXout*proj[0])
   print('Angular Straggling [mrad]  : ' ,AngularStraggling*1000.)
   print('Time of Flight [ns] : ' ,Tof)
   print('Interpolated Target thickness [mg/cm2]: ', InterpolatedTargetThickness)
   print()
   print('Energy Loss [MeV]:',(Ein-Eout)*proj[0])
   print()
  
# Another example 1GeV/u 238U on 100 um Fe
   AMU = 931.49432

   U238MassExcess = 47.3091 # in MeV
   U238Mass = 238.+ U238MassExcess/AMU
   proj = [ U238Mass, 92 ]
   targ = [[55.847, 26, 1]]
   
   density = 7.874
   isgas = 0        
   targThickness = 100.0*density/10.0 # The 10 is to convert um to cm then g to mg
   Ebeam = 1000.0      
   
   edata = atima.eloss(proj, Ebeam, targ, density, isgas, targThickness)
   
   print('1GeV/u 238U on 100 um Fe Eout [MeV/u]:', edata[1])

# An example of 1GeV/u 238U on Ar(CO2) 20% of 100 mg/cm2 at 20deg
   targ = [[12.011, 6, 2], [15.99994, 8, 4], [39.948, 18, 8]]
   density = 0.0016972
   isgas = 1        
   targThickness = 100.0
   
   edata = atima.eloss(proj, Ebeam, targ, density, isgas, targThickness)
   
   print('1GeV/u 238U on 100 mg/cm2 Ar(CO2) 20% Eout [MeV/u]:', edata[1])

 
# An example of 1GeV/u 238U on BC400 of 100 mg/cm2 
   targ = [[1.0079, 1, 10], [12.011, 6, 9]]
   density = 1.032
   isgas = 0        
   targThickness = 100.0

   edata = atima.eloss(proj, Ebeam, targ, density, isgas, targThickness)
   
   print('1GeV/u 238U on 100 mg/cm2 BC400 Eout [MeV/u]:', edata[1])

# An example of backwards calculations
   Ebeam = -900. # The minus denotes that this is the exit energy from the target
   edata = atima.eloss(proj, Ebeam, targ, density, isgas, targThickness)
   
   print('900 MeV/u 238U coming out of 100 mg/cm2 BC400 should have Ein [MeV/u]:', edata[0])

   Ebeam = -1. # What should be the beam energy to implant at depth of 100 mg/cm2 in BC400. Do not use 0!
   edata = atima.eloss(proj, Ebeam, targ, density, isgas, targThickness)
   print('E beam for implantation [MeV/u]:', edata[0])

# Or you can call calculate, as in AtimaPy1.2
   print('\nExample 238U on Be with thickness of 10 mg/cm2')
   # Example 238U on Be with thickness of 10 mg/cm2   
   proj = [ 238.011, 92 ]   # Projectile [Mass, Charge]
   targ = [[9.012, 4, 1]]   # List of target components 
                            #  [[mass number, charge, stochastic ratio],...] 
   density = 1.85           # Target density on g/cm3
   isgas = 0                # Is the target a gass 0/1 --> No/Yes
   targThickness = 10.0     # Target thickness in mg/cm2
   Ein = 100.0              # Projectile energy in MeV/u
 
# Atima returns a tuple with the calculated value, see below or
# in atima.f for description 
   (Eout, projrange ,dEdXin, dEdXout, RemainingRange,  \
    RangeStraggling , EnegergyStraggling, AngularStraggling, \
     Tof, InterpolatedTargetThickness) \
      = atima.calculate(proj, Ein, targ, density, isgas, targThickness)

#--------------------------------------------------------
   print('Ein  [MeV/u]: ' , Ein)
   print('Eout [MeV/u]: ' ,Eout)
   print('Range [mg/cm2]: ',projrange)   
   print('dEdX_in [MeV/mg/cm2]: ' ,dEdXin*proj[0])
   print('dEdX out [MeV/mg/cm2]: ' ,dEdXout*proj[0])
   print('Remaing Range[mg/cm2]  : ' ,RemainingRange)
   print('Range straggling [mg/cm2]  : ' ,RangeStraggling)
   print('Energy Straggling  [MeV] : ' ,EnegergyStraggling*dEdXout)
   print('Angular Straggling [mrad]  : ' ,AngularStraggling*1000.)
   print('Time of Flight [ns] : ' ,Tof)
   print('Interpolated Target thickness [mg/cm2]: ', InterpolatedTargetThickness)
   print('Energy Loss [MeV]:',(Ein-Eout)*proj[0])

if __name__ == "__main__": main()
